@@ -11,7 +11,7 @@ test_that('repr_html outputs the right html code', {
 	# test the content
 	no_vignettes_found = '<h3>Vignettes</h3>\n<p>No vignettes found</p>\n'
 	expect_true(nchar(html) > nchar(no_vignettes_found))  # there should be at least a few vignettes
-	expect_identical(repr_html(vignette(package = 'repr')), no_vignettes_found)
+	expect_id_text(repr_html(vignette(package = 'repr')), no_vignettes_found)
 	# we don't want to output the LibPath column
 	expect_false(grepl('LibPath', html))
 })
@@ -25,5 +25,5 @@ test_that('repr_text outputs the right text', {
 	# test the content
 	no_vignettes_found = 'no vignettes found'
 	expect_true(nchar(txt) > nchar(no_vignettes_found))  # there should be at least a few vignettes
-	expect_identical(repr_text(vignette(package = 'repr')), no_vignettes_found)
+	expect_id_text(repr_text(vignette(package = 'repr')), no_vignettes_found)
 })
